@@ -7,7 +7,7 @@ from commFunction import get_rms,make_out_file,get_ave_rms
 import numpy as np
 
 from SNR_ESTIMATION.MATCH_SIG import match_sig
-from  formatConvert.wav_pcm import get_data_array
+from commFunction import get_data_array
 
 
 speechSection = [12, 15]
